@@ -85,6 +85,18 @@ is.light_profile_multi <- function(x) {
   inherits(x, "light_profile_multi")
 }
 
+#' @describeIn is.flashlight Check for light_profile2d object.
+#' @export
+is.light_profile2d <- function(x) {
+  inherits(x, "light_profile2d")
+}
+
+#' @describeIn is.flashlight Check for light_profile2d_multi object.
+#' @export
+is.light_profile2d_multi <- function(x) {
+  inherits(x, "light_profile2d_multi")
+}
+
 #' @describeIn is.flashlight Check for light_effects object.
 #' @export
 is.light_effects <- function(x) {
