@@ -4,26 +4,20 @@
 #'
 #' @importFrom dplyr as_tibble
 #' @param x An object of class \code{flashlight} or \code{multiflashlight}.
-#' @param v The variable to be shown on the x-axis.
+#' @param v The variable name to be shown on the x-axis.
 #' @param data An optional \code{data.frame}. Not relevant for \code{type = "shap"}.
 #' @param by An optional vector of column names used to additionally group the results.
 #' @param type Type of the profile: Either "predicted", "response", "residual", or "shap".
 #' @param use_linkinv Should retransformation function be applied? Default is TRUE. Not used for \code{type = "shap"}.
 #' @param n_max Maximum number of data rows to select. Will be randomly picked from the relevant data.
 #' @param seed An integer random seed used for subsampling.
-#' @param value_name Column name in resulting \code{data} containing the values belonging to \code{type}. Defaults to "value".
-#' @param label_name Column name in resulting \code{data} containing the label of the flashlight. Defaults to "label".
-#' @param type_name Column name in the resulting \code{data} with the plot \code{type}.
 #' @param ... Further arguments passed from or to other methods.
-#' @return An object of class \code{light_scatter}, \code{light} (and a list) with the following elements.
+#' @return An object of class \code{light_scatter} with the following elements.
 #' \itemize{
-#'   \item \code{data} A tibble with results. Can be used to build fully customized visualizations.
+#'   \item \code{data} A tibble with results. Can be used to build fully customized visualizations. Column names can be controlled by \code{options(flashlight.column_name)}.
 #'   \item \code{by} Same as input \code{by}.
 #'   \item \code{v} The variable evaluated.
 #'   \item \code{type} Same as input \code{type}. For information only.
-#'   \item \code{value_name} Same as input \code{value_name}.
-#'   \item \code{label_name} Same as input \code{label_name}.
-#'   \item \code{type_name} Same as input \code{type_name}.
 #' }
 #' @export
 #' @examples
@@ -48,31 +42,44 @@ light_scatter.default <- function(x, ...) {
 #' @describeIn light_scatter Variable profile for a flashlight.
 #' @export
 light_scatter.flashlight <- function(x, v, data = x$data, by = x$by,
-                                     type = c("predicted", "response", "residual", "shap"),
-                                     use_linkinv = TRUE, n_max = 400, seed = NULL,
-                                     value_name = "value", label_name = "label",
-                                     type_name = "type", ...) {
+                                     type = c("predicted", "response",
+                                              "residual", "shap"),
+                                     use_linkinv = TRUE, n_max = 400,
+                                     seed = NULL, ...) {
   type <- match.arg(type)
 
+  warning_on_names(c("value_name", "label_name"), ...)
+
+  value_name <- getOption("flashlight.value_name")
+  label_name <- getOption("flashlight.label_name")
+
   # If SHAP, extract data
   if (type == "shap") {
     if (!is.shap(x$shap)) {
       stop("No shap values calculated. Run 'add_shap' for the flashlight first.")
     }
-    data <- x$shap$data[x$shap$data[[x$shap$variable_name]] == v, ]
+    stopifnot(v %in% colnames(x$shap$data))
+    variable_name <- getOption("flashlight.variable_name")
+    data <- x$shap$data[x$shap$data[[variable_name]] == v, ]
   }
 
   # Checks
-  vars <- c(label_name, type_name, by, v, value_name)
-  stopifnot(v %in% colnames(data),
-            (n <- nrow(data)) >= 1,
-            !anyDuplicated(vars))
+  stopifnot(
+    "No data!" = is.data.frame(data) && nrow(data) >= 1L,
+    "'by' not in 'data'!" = by %in% colnames(data),
+    "'v' not in 'data'!" = v %in% colnames(data)
+  )
+  check_unique(c(by, v), c(label_name, value_name))
+  if (type %in% c("response", "residual") && is.null(x$y)) {
+    stop("You need to specify 'y' in flashlight.")
+  }
+  n <- nrow(data)
 
   # Subsample rows if data too large
-  if (!is.null(seed)) {
-    set.seed(seed)
-  }
-  if (n_max < n) {
+  if (n > n_max) {
+    if (!is.null(seed)) {
+      set.seed(seed)
+    }
     data <- data[sample(n, n_max), , drop = FALSE]
   }
 
@@ -92,13 +99,11 @@ light_scatter.flashlight <- function(x, v, data = x$data, by = x$by,
 
   # Organize output
   data[[label_name]] <- x$label
-  data[[type_name]] <- type
-
-  out <- list(data = as_tibble(data[, vars]), by = by, v = v,
-              type = type, value_name = value_name,
-              label_name = label_name, type_name = type_name)
-  class(out) <- c("light_scatter", "light", "list")
-  out
+  vars <- c(label_name, by, v, value_name)
+  add_classes(
+    list(data = as_tibble(data[, vars]), by = by, v = v, type = type),
+    c("light_scatter", "light")
+  )
 }
 
 #' @describeIn light_scatter light_scatter for a multiflashlight.
